
<h1 align="center">
    <span style="color:#FFA566">⚙️DM</span>DD<span style="color:#FFA566">L⚙️</span>
</h1>
<div align="center">
    <a href = "https://opensource.org/licenses/MIT">
    <img  src="https://img.shields.io/badge/License-MIT-yellow.svg">
    </a>
</div>
<img src=".github/dmddl%20logo_4.png" align="center">

<h3 align="center">
    CLI tool that generates insertion script from DDL
</h3>

---
<h2>
    🖥 Installation
</h2>

To install DMDDL you may use pip:

<img src=".github/pip_install.png" align="center">


<h2>
    💡 How to use it?
</h2>

Firstly, you need to configure DMDDL using -c argument
(you can get api key from [OpenAI](https://platform.openai.com/api-keys)):



<img src=".github/configuring.gif" align="center">

Now you can use the app. Provide -s argument to specify input file: 

<img src=".github/simple_source.gif" align="center">


<h2>
    🐉 For China/Russia 🪆 
</h2>


OpenAI API blocked in this countries, but you can use -ps arguments. <br>
DMDDL will find proxy for you to make request

<img src=".github/proxy.gif" align = "center">


<h2>
    🤝 Contributing
</h2>

Contributions are welcome! <br>
If you have ideas for improving this project, please post them in issues.
<br>
(if i don't answer, you can email me)

